<template>
  <div class="container">
      <h1>My1Health AI <span class="connection_ready" v-if="connection_ready"> (Connection ready!)</span></h1>

      <div class="messages" id="messages">
        <div class="message-container">
          <h1 class="error" v-if="connection_error"> Connection error! </h1>
          <div v-for="(message,idx) in messages" :key="'m-' + idx" style="clear:both">
             <div v-if="message.type === 'user'" class="msg-from-me">
                  {{ message.text }}
                </div>
                <div v-else class="msg-from-bot">
                  {{ message.text }}
             </div>
          </div>
        </div>
      </div>

      <div class="send-message">
        <input v-model="userMessage" type="text" placeholder="Type a message" @keyup.enter="sendMessage"/>
      </div>
  </div>
</template>

<script>
import axios from "axios";

export default {
  data() {
    return {
      userMessage: '',
      messages: [],
      connection_error: false,
      connection_ready:true
    };
  },
  methods: {
    sendMessage() {
      if (this.userMessage.trim() === '') return;

      this.messages.push({ id: Date.now(), type: 'user', text: this.userMessage });
      this.userMessage = '';

      this.fetchBotResponse();
    },
    fetchBotResponse() {
      const apiUrl = 'http://localhost:8000/chat';

      axios.post(apiUrl, { message: this.messages[this.messages.length - 1].text },{
  headers: {
    'Content-Type': 'application/json',
  },
  withCredentials: true,
})
        .then(response => {

          this.messages.push({ id: Date.now(), type: 'bot', text: response.data.response });
        })
        .catch(error => {
          console.error('Error fetching bot response:', error);
        });
    },
  },
};
</script>

<style lang="less">
  body{
    background: #111b21;
  }
  .container{
    display: flex;
    flex-direction: column;
    margin: 0 auto;
    max-width: 90%;
    min-height: 98vh;
    position: relative;


    h1{
      padding: 0px;
      height: 20px;
      color: white;
      font-size: 20px;
      text-transform: uppercase;

      .connection_ready{
        color: greenyellow;
      }
    }

    .messages{
      height: 80vh;
      overflow-y: scroll;
      background-color: white;
      background-size: cover;


      .msg-from-me {
        border-radius: 7.5px;
        max-width: 65%;
        font-size: 16px;
        line-height: 19px;
        color: #e9edef;
        background: fade( #046a62, 90%);
        padding: 10px;
        margin: 20px 20px 5px 0px;

        float: right;
      }
      .msg-from-bot {
        border-radius: 7.5px;
        max-width: 65%;
        font-size: 16px;
        line-height: 19px;
        color: #e9edef;
        background: fade( #202c33, 90%);
        padding: 10px;
        margin: 20px 0px 5px 20px;
        float: left;
      }
    }
    .send-message{
      height: 62px;
      background: #536d79;
      display: flex;

      input[type='text']{
        padding: 9px 12px 11px;
        margin: 5px 10px;
        border: 1px solid #2a3942;
        background: #2a3942;
        border-radius: 8px;
        font-size: 15px;
        flex-grow: 1;
        color: white;
      }

    }
  }

</style>